# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
RWStepBasic module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_rwstepbasic.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _RWStepBasic
else:
    import _RWStepBasic

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _RWStepBasic.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _RWStepBasic.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWStepBasic.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWStepBasic.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _RWStepBasic.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _RWStepBasic.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _RWStepBasic.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _RWStepBasic.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _RWStepBasic.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _RWStepBasic.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWStepBasic.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _RWStepBasic.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _RWStepBasic.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWStepBasic.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWStepBasic.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWStepBasic.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _RWStepBasic.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _RWStepBasic:
_RWStepBasic.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _RWStepBasic.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.StepData
import OCC.Core.Interface
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Resource
import OCC.Core.StepBasic

from enum import IntEnum
from OCC.Core.Exception import *



class RWStepBasic_RWAction(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWAction_swiginit(self, _RWStepBasic.new_RWStepBasic_RWAction(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads action.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_Action

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWAction_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_Action
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWAction_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes action.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_Action

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWAction_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWAction

# Register RWStepBasic_RWAction in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWAction_swigregister(RWStepBasic_RWAction)

class RWStepBasic_RWActionAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWActionAssignment_swiginit(self, _RWStepBasic.new_RWStepBasic_RWActionAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads actionassignment.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ActionAssignment

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWActionAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_ActionAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWActionAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes actionassignment.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ActionAssignment

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWActionAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWActionAssignment

# Register RWStepBasic_RWActionAssignment in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWActionAssignment_swigregister(RWStepBasic_RWActionAssignment)

class RWStepBasic_RWActionMethod(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWActionMethod_swiginit(self, _RWStepBasic.new_RWStepBasic_RWActionMethod(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads actionmethod.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ActionMethod

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWActionMethod_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_ActionMethod
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWActionMethod_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes actionmethod.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ActionMethod

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWActionMethod_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWActionMethod

# Register RWStepBasic_RWActionMethod in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWActionMethod_swigregister(RWStepBasic_RWActionMethod)

class RWStepBasic_RWActionRequestAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWActionRequestAssignment_swiginit(self, _RWStepBasic.new_RWStepBasic_RWActionRequestAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads actionrequestassignment.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ActionRequestAssignment

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWActionRequestAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_ActionRequestAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWActionRequestAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes actionrequestassignment.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ActionRequestAssignment

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWActionRequestAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWActionRequestAssignment

# Register RWStepBasic_RWActionRequestAssignment in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWActionRequestAssignment_swigregister(RWStepBasic_RWActionRequestAssignment)

class RWStepBasic_RWActionRequestSolution(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWActionRequestSolution_swiginit(self, _RWStepBasic.new_RWStepBasic_RWActionRequestSolution(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads actionrequestsolution.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ActionRequestSolution

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWActionRequestSolution_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_ActionRequestSolution
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWActionRequestSolution_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes actionrequestsolution.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ActionRequestSolution

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWActionRequestSolution_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWActionRequestSolution

# Register RWStepBasic_RWActionRequestSolution in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWActionRequestSolution_swigregister(RWStepBasic_RWActionRequestSolution)

class RWStepBasic_RWAddress(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWAddress_swiginit(self, _RWStepBasic.new_RWStepBasic_RWAddress(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_Address

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWAddress_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_Address

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWAddress_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWAddress

# Register RWStepBasic_RWAddress in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWAddress_swigregister(RWStepBasic_RWAddress)

class RWStepBasic_RWApplicationContext(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWApplicationContext_swiginit(self, _RWStepBasic.new_RWStepBasic_RWApplicationContext(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ApplicationContext

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApplicationContext_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ApplicationContext

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApplicationContext_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWApplicationContext

# Register RWStepBasic_RWApplicationContext in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWApplicationContext_swigregister(RWStepBasic_RWApplicationContext)

class RWStepBasic_RWApplicationContextElement(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWApplicationContextElement_swiginit(self, _RWStepBasic.new_RWStepBasic_RWApplicationContextElement(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ApplicationContextElement

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApplicationContextElement_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ApplicationContextElement
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApplicationContextElement_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ApplicationContextElement

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApplicationContextElement_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWApplicationContextElement

# Register RWStepBasic_RWApplicationContextElement in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWApplicationContextElement_swigregister(RWStepBasic_RWApplicationContextElement)

class RWStepBasic_RWApplicationProtocolDefinition(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWApplicationProtocolDefinition_swiginit(self, _RWStepBasic.new_RWStepBasic_RWApplicationProtocolDefinition(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ApplicationProtocolDefinition

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApplicationProtocolDefinition_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ApplicationProtocolDefinition
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApplicationProtocolDefinition_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ApplicationProtocolDefinition

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApplicationProtocolDefinition_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWApplicationProtocolDefinition

# Register RWStepBasic_RWApplicationProtocolDefinition in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWApplicationProtocolDefinition_swigregister(RWStepBasic_RWApplicationProtocolDefinition)

class RWStepBasic_RWApproval(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWApproval_swiginit(self, _RWStepBasic.new_RWStepBasic_RWApproval(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_Approval

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApproval_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_Approval
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApproval_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_Approval

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApproval_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWApproval

# Register RWStepBasic_RWApproval in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWApproval_swigregister(RWStepBasic_RWApproval)

class RWStepBasic_RWApprovalDateTime(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWApprovalDateTime_swiginit(self, _RWStepBasic.new_RWStepBasic_RWApprovalDateTime(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ApprovalDateTime

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApprovalDateTime_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ApprovalDateTime
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApprovalDateTime_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ApprovalDateTime

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApprovalDateTime_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWApprovalDateTime

# Register RWStepBasic_RWApprovalDateTime in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWApprovalDateTime_swigregister(RWStepBasic_RWApprovalDateTime)

class RWStepBasic_RWApprovalPersonOrganization(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWApprovalPersonOrganization_swiginit(self, _RWStepBasic.new_RWStepBasic_RWApprovalPersonOrganization(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ApprovalPersonOrganization

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApprovalPersonOrganization_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ApprovalPersonOrganization
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApprovalPersonOrganization_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ApprovalPersonOrganization

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApprovalPersonOrganization_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWApprovalPersonOrganization

# Register RWStepBasic_RWApprovalPersonOrganization in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWApprovalPersonOrganization_swigregister(RWStepBasic_RWApprovalPersonOrganization)

class RWStepBasic_RWApprovalRelationship(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWApprovalRelationship_swiginit(self, _RWStepBasic.new_RWStepBasic_RWApprovalRelationship(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ApprovalRelationship

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApprovalRelationship_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ApprovalRelationship
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApprovalRelationship_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ApprovalRelationship

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApprovalRelationship_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWApprovalRelationship

# Register RWStepBasic_RWApprovalRelationship in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWApprovalRelationship_swigregister(RWStepBasic_RWApprovalRelationship)

class RWStepBasic_RWApprovalRole(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWApprovalRole_swiginit(self, _RWStepBasic.new_RWStepBasic_RWApprovalRole(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ApprovalRole

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApprovalRole_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ApprovalRole

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApprovalRole_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWApprovalRole

# Register RWStepBasic_RWApprovalRole in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWApprovalRole_swigregister(RWStepBasic_RWApprovalRole)

class RWStepBasic_RWApprovalStatus(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWApprovalStatus_swiginit(self, _RWStepBasic.new_RWStepBasic_RWApprovalStatus(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ApprovalStatus

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApprovalStatus_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ApprovalStatus

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWApprovalStatus_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWApprovalStatus

# Register RWStepBasic_RWApprovalStatus in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWApprovalStatus_swigregister(RWStepBasic_RWApprovalStatus)

class RWStepBasic_RWCalendarDate(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWCalendarDate_swiginit(self, _RWStepBasic.new_RWStepBasic_RWCalendarDate(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_CalendarDate

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWCalendarDate_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_CalendarDate

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWCalendarDate_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWCalendarDate

# Register RWStepBasic_RWCalendarDate in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWCalendarDate_swigregister(RWStepBasic_RWCalendarDate)

class RWStepBasic_RWCertification(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWCertification_swiginit(self, _RWStepBasic.new_RWStepBasic_RWCertification(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads certification.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_Certification

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWCertification_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_Certification
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWCertification_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes certification.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_Certification

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWCertification_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWCertification

# Register RWStepBasic_RWCertification in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWCertification_swigregister(RWStepBasic_RWCertification)

class RWStepBasic_RWCertificationAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWCertificationAssignment_swiginit(self, _RWStepBasic.new_RWStepBasic_RWCertificationAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads certificationassignment.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_CertificationAssignment

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWCertificationAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_CertificationAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWCertificationAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes certificationassignment.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_CertificationAssignment

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWCertificationAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWCertificationAssignment

# Register RWStepBasic_RWCertificationAssignment in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWCertificationAssignment_swigregister(RWStepBasic_RWCertificationAssignment)

class RWStepBasic_RWCertificationType(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWCertificationType_swiginit(self, _RWStepBasic.new_RWStepBasic_RWCertificationType(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads certificationtype.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_CertificationType

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWCertificationType_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_CertificationType
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWCertificationType_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes certificationtype.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_CertificationType

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWCertificationType_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWCertificationType

# Register RWStepBasic_RWCertificationType in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWCertificationType_swigregister(RWStepBasic_RWCertificationType)

class RWStepBasic_RWCharacterizedObject(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWCharacterizedObject_swiginit(self, _RWStepBasic.new_RWStepBasic_RWCharacterizedObject(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads characterizedobject.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_CharacterizedObject

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWCharacterizedObject_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_CharacterizedObject
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWCharacterizedObject_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes characterizedobject.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_CharacterizedObject

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWCharacterizedObject_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWCharacterizedObject

# Register RWStepBasic_RWCharacterizedObject in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWCharacterizedObject_swigregister(RWStepBasic_RWCharacterizedObject)

class RWStepBasic_RWContract(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWContract_swiginit(self, _RWStepBasic.new_RWStepBasic_RWContract(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads contract.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_Contract

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWContract_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_Contract
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWContract_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes contract.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_Contract

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWContract_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWContract

# Register RWStepBasic_RWContract in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWContract_swigregister(RWStepBasic_RWContract)

class RWStepBasic_RWContractAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWContractAssignment_swiginit(self, _RWStepBasic.new_RWStepBasic_RWContractAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads contractassignment.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ContractAssignment

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWContractAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_ContractAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWContractAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes contractassignment.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ContractAssignment

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWContractAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWContractAssignment

# Register RWStepBasic_RWContractAssignment in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWContractAssignment_swigregister(RWStepBasic_RWContractAssignment)

class RWStepBasic_RWContractType(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWContractType_swiginit(self, _RWStepBasic.new_RWStepBasic_RWContractType(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads contracttype.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ContractType

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWContractType_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_ContractType
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWContractType_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes contracttype.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ContractType

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWContractType_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWContractType

# Register RWStepBasic_RWContractType in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWContractType_swigregister(RWStepBasic_RWContractType)

class RWStepBasic_RWConversionBasedUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWConversionBasedUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWConversionBasedUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ConversionBasedUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ConversionBasedUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ConversionBasedUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWConversionBasedUnit

# Register RWStepBasic_RWConversionBasedUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWConversionBasedUnit_swigregister(RWStepBasic_RWConversionBasedUnit)

class RWStepBasic_RWConversionBasedUnitAndAreaUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndAreaUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWConversionBasedUnitAndAreaUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ConversionBasedUnitAndAreaUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndAreaUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ConversionBasedUnitAndAreaUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndAreaUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ConversionBasedUnitAndAreaUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndAreaUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWConversionBasedUnitAndAreaUnit

# Register RWStepBasic_RWConversionBasedUnitAndAreaUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWConversionBasedUnitAndAreaUnit_swigregister(RWStepBasic_RWConversionBasedUnitAndAreaUnit)

class RWStepBasic_RWConversionBasedUnitAndLengthUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndLengthUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWConversionBasedUnitAndLengthUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ConversionBasedUnitAndLengthUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndLengthUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ConversionBasedUnitAndLengthUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndLengthUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ConversionBasedUnitAndLengthUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndLengthUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWConversionBasedUnitAndLengthUnit

# Register RWStepBasic_RWConversionBasedUnitAndLengthUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWConversionBasedUnitAndLengthUnit_swigregister(RWStepBasic_RWConversionBasedUnitAndLengthUnit)

class RWStepBasic_RWConversionBasedUnitAndMassUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndMassUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWConversionBasedUnitAndMassUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ConversionBasedUnitAndMassUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndMassUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ConversionBasedUnitAndMassUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndMassUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ConversionBasedUnitAndMassUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndMassUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWConversionBasedUnitAndMassUnit

# Register RWStepBasic_RWConversionBasedUnitAndMassUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWConversionBasedUnitAndMassUnit_swigregister(RWStepBasic_RWConversionBasedUnitAndMassUnit)

class RWStepBasic_RWConversionBasedUnitAndPlaneAngleUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndPlaneAngleUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWConversionBasedUnitAndPlaneAngleUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ConversionBasedUnitAndPlaneAngleUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndPlaneAngleUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ConversionBasedUnitAndPlaneAngleUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndPlaneAngleUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ConversionBasedUnitAndPlaneAngleUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndPlaneAngleUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWConversionBasedUnitAndPlaneAngleUnit

# Register RWStepBasic_RWConversionBasedUnitAndPlaneAngleUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWConversionBasedUnitAndPlaneAngleUnit_swigregister(RWStepBasic_RWConversionBasedUnitAndPlaneAngleUnit)

class RWStepBasic_RWConversionBasedUnitAndRatioUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndRatioUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWConversionBasedUnitAndRatioUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ConversionBasedUnitAndRatioUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndRatioUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ConversionBasedUnitAndRatioUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndRatioUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ConversionBasedUnitAndRatioUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndRatioUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWConversionBasedUnitAndRatioUnit

# Register RWStepBasic_RWConversionBasedUnitAndRatioUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWConversionBasedUnitAndRatioUnit_swigregister(RWStepBasic_RWConversionBasedUnitAndRatioUnit)

class RWStepBasic_RWConversionBasedUnitAndSolidAngleUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndSolidAngleUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWConversionBasedUnitAndSolidAngleUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ConversionBasedUnitAndSolidAngleUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndSolidAngleUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ConversionBasedUnitAndSolidAngleUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndSolidAngleUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ConversionBasedUnitAndSolidAngleUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndSolidAngleUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWConversionBasedUnitAndSolidAngleUnit

# Register RWStepBasic_RWConversionBasedUnitAndSolidAngleUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWConversionBasedUnitAndSolidAngleUnit_swigregister(RWStepBasic_RWConversionBasedUnitAndSolidAngleUnit)

class RWStepBasic_RWConversionBasedUnitAndTimeUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndTimeUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWConversionBasedUnitAndTimeUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ConversionBasedUnitAndTimeUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndTimeUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ConversionBasedUnitAndTimeUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndTimeUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ConversionBasedUnitAndTimeUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndTimeUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWConversionBasedUnitAndTimeUnit

# Register RWStepBasic_RWConversionBasedUnitAndTimeUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWConversionBasedUnitAndTimeUnit_swigregister(RWStepBasic_RWConversionBasedUnitAndTimeUnit)

class RWStepBasic_RWConversionBasedUnitAndVolumeUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndVolumeUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWConversionBasedUnitAndVolumeUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ConversionBasedUnitAndVolumeUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndVolumeUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ConversionBasedUnitAndVolumeUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndVolumeUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ConversionBasedUnitAndVolumeUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWConversionBasedUnitAndVolumeUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWConversionBasedUnitAndVolumeUnit

# Register RWStepBasic_RWConversionBasedUnitAndVolumeUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWConversionBasedUnitAndVolumeUnit_swigregister(RWStepBasic_RWConversionBasedUnitAndVolumeUnit)

class RWStepBasic_RWCoordinatedUniversalTimeOffset(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWCoordinatedUniversalTimeOffset_swiginit(self, _RWStepBasic.new_RWStepBasic_RWCoordinatedUniversalTimeOffset(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_CoordinatedUniversalTimeOffset

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWCoordinatedUniversalTimeOffset_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_CoordinatedUniversalTimeOffset

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWCoordinatedUniversalTimeOffset_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWCoordinatedUniversalTimeOffset

# Register RWStepBasic_RWCoordinatedUniversalTimeOffset in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWCoordinatedUniversalTimeOffset_swigregister(RWStepBasic_RWCoordinatedUniversalTimeOffset)

class RWStepBasic_RWDate(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWDate_swiginit(self, _RWStepBasic.new_RWStepBasic_RWDate(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_Date

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDate_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_Date

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDate_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWDate

# Register RWStepBasic_RWDate in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWDate_swigregister(RWStepBasic_RWDate)

class RWStepBasic_RWDateAndTime(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWDateAndTime_swiginit(self, _RWStepBasic.new_RWStepBasic_RWDateAndTime(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_DateAndTime

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDateAndTime_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_DateAndTime
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDateAndTime_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_DateAndTime

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDateAndTime_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWDateAndTime

# Register RWStepBasic_RWDateAndTime in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWDateAndTime_swigregister(RWStepBasic_RWDateAndTime)

class RWStepBasic_RWDateRole(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWDateRole_swiginit(self, _RWStepBasic.new_RWStepBasic_RWDateRole(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_DateRole

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDateRole_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_DateRole

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDateRole_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWDateRole

# Register RWStepBasic_RWDateRole in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWDateRole_swigregister(RWStepBasic_RWDateRole)

class RWStepBasic_RWDateTimeRole(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWDateTimeRole_swiginit(self, _RWStepBasic.new_RWStepBasic_RWDateTimeRole(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_DateTimeRole

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDateTimeRole_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_DateTimeRole

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDateTimeRole_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWDateTimeRole

# Register RWStepBasic_RWDateTimeRole in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWDateTimeRole_swigregister(RWStepBasic_RWDateTimeRole)

class RWStepBasic_RWDerivedUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWDerivedUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWDerivedUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_DerivedUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDerivedUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_DerivedUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDerivedUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_DerivedUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDerivedUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWDerivedUnit

# Register RWStepBasic_RWDerivedUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWDerivedUnit_swigregister(RWStepBasic_RWDerivedUnit)

class RWStepBasic_RWDerivedUnitElement(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWDerivedUnitElement_swiginit(self, _RWStepBasic.new_RWStepBasic_RWDerivedUnitElement(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_DerivedUnitElement

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDerivedUnitElement_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_DerivedUnitElement
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDerivedUnitElement_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_DerivedUnitElement

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDerivedUnitElement_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWDerivedUnitElement

# Register RWStepBasic_RWDerivedUnitElement in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWDerivedUnitElement_swigregister(RWStepBasic_RWDerivedUnitElement)

class RWStepBasic_RWDimensionalExponents(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWDimensionalExponents_swiginit(self, _RWStepBasic.new_RWStepBasic_RWDimensionalExponents(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_DimensionalExponents

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDimensionalExponents_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_DimensionalExponents

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDimensionalExponents_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWDimensionalExponents

# Register RWStepBasic_RWDimensionalExponents in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWDimensionalExponents_swigregister(RWStepBasic_RWDimensionalExponents)

class RWStepBasic_RWDocument(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWDocument_swiginit(self, _RWStepBasic.new_RWStepBasic_RWDocument(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads document.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_Document

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocument_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_Document
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocument_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes document.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_Document

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocument_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWDocument

# Register RWStepBasic_RWDocument in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWDocument_swigregister(RWStepBasic_RWDocument)

class RWStepBasic_RWDocumentFile(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWDocumentFile_swiginit(self, _RWStepBasic.new_RWStepBasic_RWDocumentFile(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads documentfile.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_DocumentFile

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocumentFile_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_DocumentFile
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocumentFile_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes documentfile.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_DocumentFile

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocumentFile_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWDocumentFile

# Register RWStepBasic_RWDocumentFile in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWDocumentFile_swigregister(RWStepBasic_RWDocumentFile)

class RWStepBasic_RWDocumentProductAssociation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWDocumentProductAssociation_swiginit(self, _RWStepBasic.new_RWStepBasic_RWDocumentProductAssociation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads documentproductassociation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_DocumentProductAssociation

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocumentProductAssociation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_DocumentProductAssociation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocumentProductAssociation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes documentproductassociation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_DocumentProductAssociation

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocumentProductAssociation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWDocumentProductAssociation

# Register RWStepBasic_RWDocumentProductAssociation in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWDocumentProductAssociation_swigregister(RWStepBasic_RWDocumentProductAssociation)

class RWStepBasic_RWDocumentProductEquivalence(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWDocumentProductEquivalence_swiginit(self, _RWStepBasic.new_RWStepBasic_RWDocumentProductEquivalence(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads documentproductequivalence.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_DocumentProductEquivalence

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocumentProductEquivalence_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_DocumentProductEquivalence
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocumentProductEquivalence_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes documentproductequivalence.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_DocumentProductEquivalence

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocumentProductEquivalence_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWDocumentProductEquivalence

# Register RWStepBasic_RWDocumentProductEquivalence in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWDocumentProductEquivalence_swigregister(RWStepBasic_RWDocumentProductEquivalence)

class RWStepBasic_RWDocumentRelationship(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWDocumentRelationship_swiginit(self, _RWStepBasic.new_RWStepBasic_RWDocumentRelationship(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_DocumentRelationship

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocumentRelationship_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_DocumentRelationship
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocumentRelationship_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_DocumentRelationship

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocumentRelationship_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWDocumentRelationship

# Register RWStepBasic_RWDocumentRelationship in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWDocumentRelationship_swigregister(RWStepBasic_RWDocumentRelationship)

class RWStepBasic_RWDocumentRepresentationType(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWDocumentRepresentationType_swiginit(self, _RWStepBasic.new_RWStepBasic_RWDocumentRepresentationType(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads documentrepresentationtype.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_DocumentRepresentationType

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocumentRepresentationType_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_DocumentRepresentationType
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocumentRepresentationType_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes documentrepresentationtype.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_DocumentRepresentationType

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocumentRepresentationType_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWDocumentRepresentationType

# Register RWStepBasic_RWDocumentRepresentationType in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWDocumentRepresentationType_swigregister(RWStepBasic_RWDocumentRepresentationType)

class RWStepBasic_RWDocumentType(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWDocumentType_swiginit(self, _RWStepBasic.new_RWStepBasic_RWDocumentType(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_DocumentType

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocumentType_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_DocumentType
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocumentType_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_DocumentType

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocumentType_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWDocumentType

# Register RWStepBasic_RWDocumentType in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWDocumentType_swigregister(RWStepBasic_RWDocumentType)

class RWStepBasic_RWDocumentUsageConstraint(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWDocumentUsageConstraint_swiginit(self, _RWStepBasic.new_RWStepBasic_RWDocumentUsageConstraint(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_DocumentUsageConstraint

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocumentUsageConstraint_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_DocumentUsageConstraint
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocumentUsageConstraint_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_DocumentUsageConstraint

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWDocumentUsageConstraint_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWDocumentUsageConstraint

# Register RWStepBasic_RWDocumentUsageConstraint in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWDocumentUsageConstraint_swigregister(RWStepBasic_RWDocumentUsageConstraint)

class RWStepBasic_RWEffectivity(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWEffectivity_swiginit(self, _RWStepBasic.new_RWStepBasic_RWEffectivity(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_Effectivity

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWEffectivity_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_Effectivity
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWEffectivity_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_Effectivity

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWEffectivity_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWEffectivity

# Register RWStepBasic_RWEffectivity in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWEffectivity_swigregister(RWStepBasic_RWEffectivity)

class RWStepBasic_RWEffectivityAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWEffectivityAssignment_swiginit(self, _RWStepBasic.new_RWStepBasic_RWEffectivityAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads effectivityassignment.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_EffectivityAssignment

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWEffectivityAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_EffectivityAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWEffectivityAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes effectivityassignment.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_EffectivityAssignment

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWEffectivityAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWEffectivityAssignment

# Register RWStepBasic_RWEffectivityAssignment in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWEffectivityAssignment_swigregister(RWStepBasic_RWEffectivityAssignment)

class RWStepBasic_RWEulerAngles(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWEulerAngles_swiginit(self, _RWStepBasic.new_RWStepBasic_RWEulerAngles(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads eulerangles.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_EulerAngles

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWEulerAngles_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_EulerAngles
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWEulerAngles_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes eulerangles.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_EulerAngles

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWEulerAngles_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWEulerAngles

# Register RWStepBasic_RWEulerAngles in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWEulerAngles_swigregister(RWStepBasic_RWEulerAngles)

class RWStepBasic_RWExternalIdentificationAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWExternalIdentificationAssignment_swiginit(self, _RWStepBasic.new_RWStepBasic_RWExternalIdentificationAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads externalidentificationassignment.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ExternalIdentificationAssignment

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWExternalIdentificationAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_ExternalIdentificationAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWExternalIdentificationAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes externalidentificationassignment.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ExternalIdentificationAssignment

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWExternalIdentificationAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWExternalIdentificationAssignment

# Register RWStepBasic_RWExternalIdentificationAssignment in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWExternalIdentificationAssignment_swigregister(RWStepBasic_RWExternalIdentificationAssignment)

class RWStepBasic_RWExternalSource(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWExternalSource_swiginit(self, _RWStepBasic.new_RWStepBasic_RWExternalSource(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads externalsource.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ExternalSource

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWExternalSource_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_ExternalSource
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWExternalSource_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes externalsource.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ExternalSource

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWExternalSource_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWExternalSource

# Register RWStepBasic_RWExternalSource in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWExternalSource_swigregister(RWStepBasic_RWExternalSource)

class RWStepBasic_RWExternallyDefinedItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWExternallyDefinedItem_swiginit(self, _RWStepBasic.new_RWStepBasic_RWExternallyDefinedItem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads externallydefineditem.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ExternallyDefinedItem

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWExternallyDefinedItem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_ExternallyDefinedItem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWExternallyDefinedItem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes externallydefineditem.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ExternallyDefinedItem

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWExternallyDefinedItem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWExternallyDefinedItem

# Register RWStepBasic_RWExternallyDefinedItem in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWExternallyDefinedItem_swigregister(RWStepBasic_RWExternallyDefinedItem)

class RWStepBasic_RWGeneralProperty(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWGeneralProperty_swiginit(self, _RWStepBasic.new_RWStepBasic_RWGeneralProperty(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads generalproperty.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_GeneralProperty

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWGeneralProperty_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_GeneralProperty
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWGeneralProperty_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes generalproperty.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_GeneralProperty

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWGeneralProperty_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWGeneralProperty

# Register RWStepBasic_RWGeneralProperty in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWGeneralProperty_swigregister(RWStepBasic_RWGeneralProperty)

class RWStepBasic_RWGroup(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWGroup_swiginit(self, _RWStepBasic.new_RWStepBasic_RWGroup(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads group.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_Group

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWGroup_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_Group
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWGroup_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes group.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_Group

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWGroup_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWGroup

# Register RWStepBasic_RWGroup in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWGroup_swigregister(RWStepBasic_RWGroup)

class RWStepBasic_RWGroupAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWGroupAssignment_swiginit(self, _RWStepBasic.new_RWStepBasic_RWGroupAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads groupassignment.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_GroupAssignment

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWGroupAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_GroupAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWGroupAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes groupassignment.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_GroupAssignment

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWGroupAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWGroupAssignment

# Register RWStepBasic_RWGroupAssignment in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWGroupAssignment_swigregister(RWStepBasic_RWGroupAssignment)

class RWStepBasic_RWGroupRelationship(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWGroupRelationship_swiginit(self, _RWStepBasic.new_RWStepBasic_RWGroupRelationship(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads grouprelationship.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_GroupRelationship

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWGroupRelationship_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_GroupRelationship
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWGroupRelationship_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes grouprelationship.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_GroupRelationship

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWGroupRelationship_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWGroupRelationship

# Register RWStepBasic_RWGroupRelationship in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWGroupRelationship_swigregister(RWStepBasic_RWGroupRelationship)

class RWStepBasic_RWIdentificationAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWIdentificationAssignment_swiginit(self, _RWStepBasic.new_RWStepBasic_RWIdentificationAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads identificationassignment.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_IdentificationAssignment

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWIdentificationAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_IdentificationAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWIdentificationAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes identificationassignment.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_IdentificationAssignment

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWIdentificationAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWIdentificationAssignment

# Register RWStepBasic_RWIdentificationAssignment in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWIdentificationAssignment_swigregister(RWStepBasic_RWIdentificationAssignment)

class RWStepBasic_RWIdentificationRole(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWIdentificationRole_swiginit(self, _RWStepBasic.new_RWStepBasic_RWIdentificationRole(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads identificationrole.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_IdentificationRole

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWIdentificationRole_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_IdentificationRole
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWIdentificationRole_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes identificationrole.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_IdentificationRole

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWIdentificationRole_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWIdentificationRole

# Register RWStepBasic_RWIdentificationRole in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWIdentificationRole_swigregister(RWStepBasic_RWIdentificationRole)

class RWStepBasic_RWLengthMeasureWithUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWLengthMeasureWithUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWLengthMeasureWithUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_LengthMeasureWithUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWLengthMeasureWithUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_LengthMeasureWithUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWLengthMeasureWithUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_LengthMeasureWithUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWLengthMeasureWithUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWLengthMeasureWithUnit

# Register RWStepBasic_RWLengthMeasureWithUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWLengthMeasureWithUnit_swigregister(RWStepBasic_RWLengthMeasureWithUnit)

class RWStepBasic_RWLengthUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWLengthUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWLengthUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_LengthUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWLengthUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_LengthUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWLengthUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_LengthUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWLengthUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWLengthUnit

# Register RWStepBasic_RWLengthUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWLengthUnit_swigregister(RWStepBasic_RWLengthUnit)

class RWStepBasic_RWLocalTime(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWLocalTime_swiginit(self, _RWStepBasic.new_RWStepBasic_RWLocalTime(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_LocalTime

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWLocalTime_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_LocalTime
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWLocalTime_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_LocalTime

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWLocalTime_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWLocalTime

# Register RWStepBasic_RWLocalTime in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWLocalTime_swigregister(RWStepBasic_RWLocalTime)

class RWStepBasic_RWMassMeasureWithUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWMassMeasureWithUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWMassMeasureWithUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_MassMeasureWithUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWMassMeasureWithUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_MassMeasureWithUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWMassMeasureWithUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_MassMeasureWithUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWMassMeasureWithUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWMassMeasureWithUnit

# Register RWStepBasic_RWMassMeasureWithUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWMassMeasureWithUnit_swigregister(RWStepBasic_RWMassMeasureWithUnit)

class RWStepBasic_RWMassUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWMassUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWMassUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads massunit.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_MassUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWMassUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_MassUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWMassUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes massunit.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_MassUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWMassUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWMassUnit

# Register RWStepBasic_RWMassUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWMassUnit_swigregister(RWStepBasic_RWMassUnit)

class RWStepBasic_RWMeasureWithUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWMeasureWithUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWMeasureWithUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_MeasureWithUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWMeasureWithUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_MeasureWithUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWMeasureWithUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_MeasureWithUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWMeasureWithUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWMeasureWithUnit

# Register RWStepBasic_RWMeasureWithUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWMeasureWithUnit_swigregister(RWStepBasic_RWMeasureWithUnit)

class RWStepBasic_RWMechanicalContext(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWMechanicalContext_swiginit(self, _RWStepBasic.new_RWStepBasic_RWMechanicalContext(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_MechanicalContext

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWMechanicalContext_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_MechanicalContext
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWMechanicalContext_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_MechanicalContext

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWMechanicalContext_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWMechanicalContext

# Register RWStepBasic_RWMechanicalContext in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWMechanicalContext_swigregister(RWStepBasic_RWMechanicalContext)

class RWStepBasic_RWNameAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWNameAssignment_swiginit(self, _RWStepBasic.new_RWStepBasic_RWNameAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads nameassignment.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_NameAssignment

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWNameAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_NameAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWNameAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes nameassignment.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_NameAssignment

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWNameAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWNameAssignment

# Register RWStepBasic_RWNameAssignment in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWNameAssignment_swigregister(RWStepBasic_RWNameAssignment)

class RWStepBasic_RWNamedUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWNamedUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWNamedUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_NamedUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWNamedUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_NamedUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWNamedUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_NamedUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWNamedUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWNamedUnit

# Register RWStepBasic_RWNamedUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWNamedUnit_swigregister(RWStepBasic_RWNamedUnit)

class RWStepBasic_RWObjectRole(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWObjectRole_swiginit(self, _RWStepBasic.new_RWStepBasic_RWObjectRole(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads objectrole.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ObjectRole

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWObjectRole_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_ObjectRole
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWObjectRole_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes objectrole.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ObjectRole

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWObjectRole_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWObjectRole

# Register RWStepBasic_RWObjectRole in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWObjectRole_swigregister(RWStepBasic_RWObjectRole)

class RWStepBasic_RWOrdinalDate(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWOrdinalDate_swiginit(self, _RWStepBasic.new_RWStepBasic_RWOrdinalDate(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_OrdinalDate

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWOrdinalDate_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_OrdinalDate

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWOrdinalDate_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWOrdinalDate

# Register RWStepBasic_RWOrdinalDate in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWOrdinalDate_swigregister(RWStepBasic_RWOrdinalDate)

class RWStepBasic_RWOrganization(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWOrganization_swiginit(self, _RWStepBasic.new_RWStepBasic_RWOrganization(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_Organization

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWOrganization_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_Organization

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWOrganization_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWOrganization

# Register RWStepBasic_RWOrganization in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWOrganization_swigregister(RWStepBasic_RWOrganization)

class RWStepBasic_RWOrganizationRole(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWOrganizationRole_swiginit(self, _RWStepBasic.new_RWStepBasic_RWOrganizationRole(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_OrganizationRole

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWOrganizationRole_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_OrganizationRole

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWOrganizationRole_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWOrganizationRole

# Register RWStepBasic_RWOrganizationRole in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWOrganizationRole_swigregister(RWStepBasic_RWOrganizationRole)

class RWStepBasic_RWOrganizationalAddress(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWOrganizationalAddress_swiginit(self, _RWStepBasic.new_RWStepBasic_RWOrganizationalAddress(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_OrganizationalAddress

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWOrganizationalAddress_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_OrganizationalAddress
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWOrganizationalAddress_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_OrganizationalAddress

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWOrganizationalAddress_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWOrganizationalAddress

# Register RWStepBasic_RWOrganizationalAddress in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWOrganizationalAddress_swigregister(RWStepBasic_RWOrganizationalAddress)

class RWStepBasic_RWPerson(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWPerson_swiginit(self, _RWStepBasic.new_RWStepBasic_RWPerson(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_Person

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWPerson_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_Person

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWPerson_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWPerson

# Register RWStepBasic_RWPerson in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWPerson_swigregister(RWStepBasic_RWPerson)

class RWStepBasic_RWPersonAndOrganization(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWPersonAndOrganization_swiginit(self, _RWStepBasic.new_RWStepBasic_RWPersonAndOrganization(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_PersonAndOrganization

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWPersonAndOrganization_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_PersonAndOrganization
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWPersonAndOrganization_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_PersonAndOrganization

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWPersonAndOrganization_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWPersonAndOrganization

# Register RWStepBasic_RWPersonAndOrganization in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWPersonAndOrganization_swigregister(RWStepBasic_RWPersonAndOrganization)

class RWStepBasic_RWPersonAndOrganizationRole(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWPersonAndOrganizationRole_swiginit(self, _RWStepBasic.new_RWStepBasic_RWPersonAndOrganizationRole(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_PersonAndOrganizationRole

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWPersonAndOrganizationRole_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_PersonAndOrganizationRole

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWPersonAndOrganizationRole_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWPersonAndOrganizationRole

# Register RWStepBasic_RWPersonAndOrganizationRole in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWPersonAndOrganizationRole_swigregister(RWStepBasic_RWPersonAndOrganizationRole)

class RWStepBasic_RWPersonalAddress(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWPersonalAddress_swiginit(self, _RWStepBasic.new_RWStepBasic_RWPersonalAddress(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_PersonalAddress

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWPersonalAddress_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_PersonalAddress
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWPersonalAddress_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_PersonalAddress

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWPersonalAddress_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWPersonalAddress

# Register RWStepBasic_RWPersonalAddress in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWPersonalAddress_swigregister(RWStepBasic_RWPersonalAddress)

class RWStepBasic_RWPlaneAngleMeasureWithUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWPlaneAngleMeasureWithUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWPlaneAngleMeasureWithUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_PlaneAngleMeasureWithUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWPlaneAngleMeasureWithUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_PlaneAngleMeasureWithUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWPlaneAngleMeasureWithUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_PlaneAngleMeasureWithUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWPlaneAngleMeasureWithUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWPlaneAngleMeasureWithUnit

# Register RWStepBasic_RWPlaneAngleMeasureWithUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWPlaneAngleMeasureWithUnit_swigregister(RWStepBasic_RWPlaneAngleMeasureWithUnit)

class RWStepBasic_RWPlaneAngleUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWPlaneAngleUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWPlaneAngleUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_PlaneAngleUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWPlaneAngleUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_PlaneAngleUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWPlaneAngleUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_PlaneAngleUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWPlaneAngleUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWPlaneAngleUnit

# Register RWStepBasic_RWPlaneAngleUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWPlaneAngleUnit_swigregister(RWStepBasic_RWPlaneAngleUnit)

class RWStepBasic_RWProduct(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWProduct_swiginit(self, _RWStepBasic.new_RWStepBasic_RWProduct(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_Product

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProduct_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_Product
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProduct_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_Product

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProduct_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWProduct

# Register RWStepBasic_RWProduct in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWProduct_swigregister(RWStepBasic_RWProduct)

class RWStepBasic_RWProductCategory(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWProductCategory_swiginit(self, _RWStepBasic.new_RWStepBasic_RWProductCategory(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ProductCategory

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductCategory_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ProductCategory

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductCategory_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWProductCategory

# Register RWStepBasic_RWProductCategory in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWProductCategory_swigregister(RWStepBasic_RWProductCategory)

class RWStepBasic_RWProductCategoryRelationship(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWProductCategoryRelationship_swiginit(self, _RWStepBasic.new_RWStepBasic_RWProductCategoryRelationship(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads productcategoryrelationship.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ProductCategoryRelationship

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductCategoryRelationship_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_ProductCategoryRelationship
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductCategoryRelationship_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes productcategoryrelationship.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ProductCategoryRelationship

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductCategoryRelationship_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWProductCategoryRelationship

# Register RWStepBasic_RWProductCategoryRelationship in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWProductCategoryRelationship_swigregister(RWStepBasic_RWProductCategoryRelationship)

class RWStepBasic_RWProductConceptContext(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWProductConceptContext_swiginit(self, _RWStepBasic.new_RWStepBasic_RWProductConceptContext(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads productconceptcontext.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ProductConceptContext

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductConceptContext_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_ProductConceptContext
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductConceptContext_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes productconceptcontext.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ProductConceptContext

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductConceptContext_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWProductConceptContext

# Register RWStepBasic_RWProductConceptContext in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWProductConceptContext_swigregister(RWStepBasic_RWProductConceptContext)

class RWStepBasic_RWProductContext(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWProductContext_swiginit(self, _RWStepBasic.new_RWStepBasic_RWProductContext(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ProductContext

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductContext_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ProductContext
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductContext_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ProductContext

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductContext_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWProductContext

# Register RWStepBasic_RWProductContext in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWProductContext_swigregister(RWStepBasic_RWProductContext)

class RWStepBasic_RWProductDefinition(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWProductDefinition_swiginit(self, _RWStepBasic.new_RWStepBasic_RWProductDefinition(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ProductDefinition

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinition_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ProductDefinition
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinition_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ProductDefinition

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinition_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWProductDefinition

# Register RWStepBasic_RWProductDefinition in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWProductDefinition_swigregister(RWStepBasic_RWProductDefinition)

class RWStepBasic_RWProductDefinitionContext(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWProductDefinitionContext_swiginit(self, _RWStepBasic.new_RWStepBasic_RWProductDefinitionContext(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ProductDefinitionContext

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionContext_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ProductDefinitionContext
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionContext_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ProductDefinitionContext

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionContext_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWProductDefinitionContext

# Register RWStepBasic_RWProductDefinitionContext in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWProductDefinitionContext_swigregister(RWStepBasic_RWProductDefinitionContext)

class RWStepBasic_RWProductDefinitionEffectivity(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWProductDefinitionEffectivity_swiginit(self, _RWStepBasic.new_RWStepBasic_RWProductDefinitionEffectivity(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ProductDefinitionEffectivity

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionEffectivity_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ProductDefinitionEffectivity
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionEffectivity_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ProductDefinitionEffectivity

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionEffectivity_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWProductDefinitionEffectivity

# Register RWStepBasic_RWProductDefinitionEffectivity in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWProductDefinitionEffectivity_swigregister(RWStepBasic_RWProductDefinitionEffectivity)

class RWStepBasic_RWProductDefinitionFormation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWProductDefinitionFormation_swiginit(self, _RWStepBasic.new_RWStepBasic_RWProductDefinitionFormation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ProductDefinitionFormation

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionFormation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ProductDefinitionFormation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionFormation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ProductDefinitionFormation

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionFormation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWProductDefinitionFormation

# Register RWStepBasic_RWProductDefinitionFormation in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWProductDefinitionFormation_swigregister(RWStepBasic_RWProductDefinitionFormation)

class RWStepBasic_RWProductDefinitionFormationRelationship(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWProductDefinitionFormationRelationship_swiginit(self, _RWStepBasic.new_RWStepBasic_RWProductDefinitionFormationRelationship(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads productdefinitionformationrelationship.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ProductDefinitionFormationRelationship

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionFormationRelationship_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_ProductDefinitionFormationRelationship
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionFormationRelationship_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes productdefinitionformationrelationship.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ProductDefinitionFormationRelationship

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionFormationRelationship_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWProductDefinitionFormationRelationship

# Register RWStepBasic_RWProductDefinitionFormationRelationship in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWProductDefinitionFormationRelationship_swigregister(RWStepBasic_RWProductDefinitionFormationRelationship)

class RWStepBasic_RWProductDefinitionFormationWithSpecifiedSource(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWProductDefinitionFormationWithSpecifiedSource_swiginit(self, _RWStepBasic.new_RWStepBasic_RWProductDefinitionFormationWithSpecifiedSource(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ProductDefinitionFormationWithSpecifiedSource

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionFormationWithSpecifiedSource_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ProductDefinitionFormationWithSpecifiedSource
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionFormationWithSpecifiedSource_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ProductDefinitionFormationWithSpecifiedSource

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionFormationWithSpecifiedSource_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWProductDefinitionFormationWithSpecifiedSource

# Register RWStepBasic_RWProductDefinitionFormationWithSpecifiedSource in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWProductDefinitionFormationWithSpecifiedSource_swigregister(RWStepBasic_RWProductDefinitionFormationWithSpecifiedSource)

class RWStepBasic_RWProductDefinitionReference(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWProductDefinitionReference_swiginit(self, _RWStepBasic.new_RWStepBasic_RWProductDefinitionReference(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ProductDefinitionReference

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionReference_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ProductDefinitionReference
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionReference_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ProductDefinitionReference

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionReference_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWProductDefinitionReference

# Register RWStepBasic_RWProductDefinitionReference in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWProductDefinitionReference_swigregister(RWStepBasic_RWProductDefinitionReference)

class RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation_swiginit(self, _RWStepBasic.new_RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ProductDefinitionReferenceWithLocalRepresentation

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ProductDefinitionReferenceWithLocalRepresentation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ProductDefinitionReferenceWithLocalRepresentation

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation

# Register RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation_swigregister(RWStepBasic_RWProductDefinitionReferenceWithLocalRepresentation)

class RWStepBasic_RWProductDefinitionRelationship(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWProductDefinitionRelationship_swiginit(self, _RWStepBasic.new_RWStepBasic_RWProductDefinitionRelationship(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads productdefinitionrelationship.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ProductDefinitionRelationship

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionRelationship_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_ProductDefinitionRelationship
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionRelationship_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes productdefinitionrelationship.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ProductDefinitionRelationship

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionRelationship_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWProductDefinitionRelationship

# Register RWStepBasic_RWProductDefinitionRelationship in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWProductDefinitionRelationship_swigregister(RWStepBasic_RWProductDefinitionRelationship)

class RWStepBasic_RWProductDefinitionWithAssociatedDocuments(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWProductDefinitionWithAssociatedDocuments_swiginit(self, _RWStepBasic.new_RWStepBasic_RWProductDefinitionWithAssociatedDocuments(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ProductDefinitionWithAssociatedDocuments

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionWithAssociatedDocuments_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ProductDefinitionWithAssociatedDocuments
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionWithAssociatedDocuments_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ProductDefinitionWithAssociatedDocuments

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductDefinitionWithAssociatedDocuments_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWProductDefinitionWithAssociatedDocuments

# Register RWStepBasic_RWProductDefinitionWithAssociatedDocuments in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWProductDefinitionWithAssociatedDocuments_swigregister(RWStepBasic_RWProductDefinitionWithAssociatedDocuments)

class RWStepBasic_RWProductRelatedProductCategory(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWProductRelatedProductCategory_swiginit(self, _RWStepBasic.new_RWStepBasic_RWProductRelatedProductCategory(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ProductRelatedProductCategory

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductRelatedProductCategory_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ProductRelatedProductCategory
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductRelatedProductCategory_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ProductRelatedProductCategory

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductRelatedProductCategory_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWProductRelatedProductCategory

# Register RWStepBasic_RWProductRelatedProductCategory in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWProductRelatedProductCategory_swigregister(RWStepBasic_RWProductRelatedProductCategory)

class RWStepBasic_RWProductType(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWProductType_swiginit(self, _RWStepBasic.new_RWStepBasic_RWProductType(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ProductType

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductType_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_ProductType
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductType_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ProductType

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWProductType_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWProductType

# Register RWStepBasic_RWProductType in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWProductType_swigregister(RWStepBasic_RWProductType)

class RWStepBasic_RWRatioMeasureWithUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWRatioMeasureWithUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWRatioMeasureWithUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_RatioMeasureWithUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWRatioMeasureWithUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_RatioMeasureWithUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWRatioMeasureWithUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_RatioMeasureWithUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWRatioMeasureWithUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWRatioMeasureWithUnit

# Register RWStepBasic_RWRatioMeasureWithUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWRatioMeasureWithUnit_swigregister(RWStepBasic_RWRatioMeasureWithUnit)

class RWStepBasic_RWRoleAssociation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWRoleAssociation_swiginit(self, _RWStepBasic.new_RWStepBasic_RWRoleAssociation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads roleassociation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_RoleAssociation

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWRoleAssociation_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_RoleAssociation
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWRoleAssociation_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes roleassociation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_RoleAssociation

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWRoleAssociation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWRoleAssociation

# Register RWStepBasic_RWRoleAssociation in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWRoleAssociation_swigregister(RWStepBasic_RWRoleAssociation)

class RWStepBasic_RWSecurityClassification(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWSecurityClassification_swiginit(self, _RWStepBasic.new_RWStepBasic_RWSecurityClassification(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_SecurityClassification

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSecurityClassification_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_SecurityClassification
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSecurityClassification_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_SecurityClassification

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSecurityClassification_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWSecurityClassification

# Register RWStepBasic_RWSecurityClassification in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWSecurityClassification_swigregister(RWStepBasic_RWSecurityClassification)

class RWStepBasic_RWSecurityClassificationLevel(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWSecurityClassificationLevel_swiginit(self, _RWStepBasic.new_RWStepBasic_RWSecurityClassificationLevel(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_SecurityClassificationLevel

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSecurityClassificationLevel_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_SecurityClassificationLevel

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSecurityClassificationLevel_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWSecurityClassificationLevel

# Register RWStepBasic_RWSecurityClassificationLevel in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWSecurityClassificationLevel_swigregister(RWStepBasic_RWSecurityClassificationLevel)

class RWStepBasic_RWSiUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWSiUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWSiUnit(*args))

    def DecodeName(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: StepBasic_SiUnitName
        text: char *

        Returns
        -------
        bool

        """
        return _RWStepBasic.RWStepBasic_RWSiUnit_DecodeName(self, *args)

    def DecodePrefix(self, *args) -> "Standard_Boolean":
        r"""
        No available documentation.

        Parameters
        ----------
        aPrefix: StepBasic_SiPrefix
        text: char *

        Returns
        -------
        bool

        """
        return _RWStepBasic.RWStepBasic_RWSiUnit_DecodePrefix(self, *args)

    def EncodeName(self, *args) -> "TCollection_AsciiString":
        r"""
        No available documentation.

        Parameters
        ----------
        aName: StepBasic_SiUnitName

        Returns
        -------
        TCollection_AsciiString

        """
        return _RWStepBasic.RWStepBasic_RWSiUnit_EncodeName(self, *args)

    def EncodePrefix(self, *args) -> "TCollection_AsciiString":
        r"""
        No available documentation.

        Parameters
        ----------
        aPrefix: StepBasic_SiPrefix

        Returns
        -------
        TCollection_AsciiString

        """
        return _RWStepBasic.RWStepBasic_RWSiUnit_EncodePrefix(self, *args)

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_SiUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSiUnit_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_SiUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSiUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWSiUnit

# Register RWStepBasic_RWSiUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWSiUnit_swigregister(RWStepBasic_RWSiUnit)

class RWStepBasic_RWSiUnitAndAreaUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWSiUnitAndAreaUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWSiUnitAndAreaUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_SiUnitAndAreaUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSiUnitAndAreaUnit_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_SiUnitAndAreaUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSiUnitAndAreaUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWSiUnitAndAreaUnit

# Register RWStepBasic_RWSiUnitAndAreaUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWSiUnitAndAreaUnit_swigregister(RWStepBasic_RWSiUnitAndAreaUnit)

class RWStepBasic_RWSiUnitAndLengthUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWSiUnitAndLengthUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWSiUnitAndLengthUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_SiUnitAndLengthUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSiUnitAndLengthUnit_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_SiUnitAndLengthUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSiUnitAndLengthUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWSiUnitAndLengthUnit

# Register RWStepBasic_RWSiUnitAndLengthUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWSiUnitAndLengthUnit_swigregister(RWStepBasic_RWSiUnitAndLengthUnit)

class RWStepBasic_RWSiUnitAndMassUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWSiUnitAndMassUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWSiUnitAndMassUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_SiUnitAndMassUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSiUnitAndMassUnit_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_SiUnitAndMassUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSiUnitAndMassUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWSiUnitAndMassUnit

# Register RWStepBasic_RWSiUnitAndMassUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWSiUnitAndMassUnit_swigregister(RWStepBasic_RWSiUnitAndMassUnit)

class RWStepBasic_RWSiUnitAndPlaneAngleUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWSiUnitAndPlaneAngleUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWSiUnitAndPlaneAngleUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_SiUnitAndPlaneAngleUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSiUnitAndPlaneAngleUnit_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_SiUnitAndPlaneAngleUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSiUnitAndPlaneAngleUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWSiUnitAndPlaneAngleUnit

# Register RWStepBasic_RWSiUnitAndPlaneAngleUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWSiUnitAndPlaneAngleUnit_swigregister(RWStepBasic_RWSiUnitAndPlaneAngleUnit)

class RWStepBasic_RWSiUnitAndRatioUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWSiUnitAndRatioUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWSiUnitAndRatioUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_SiUnitAndRatioUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSiUnitAndRatioUnit_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_SiUnitAndRatioUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSiUnitAndRatioUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWSiUnitAndRatioUnit

# Register RWStepBasic_RWSiUnitAndRatioUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWSiUnitAndRatioUnit_swigregister(RWStepBasic_RWSiUnitAndRatioUnit)

class RWStepBasic_RWSiUnitAndSolidAngleUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWSiUnitAndSolidAngleUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWSiUnitAndSolidAngleUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_SiUnitAndSolidAngleUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSiUnitAndSolidAngleUnit_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_SiUnitAndSolidAngleUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSiUnitAndSolidAngleUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWSiUnitAndSolidAngleUnit

# Register RWStepBasic_RWSiUnitAndSolidAngleUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWSiUnitAndSolidAngleUnit_swigregister(RWStepBasic_RWSiUnitAndSolidAngleUnit)

class RWStepBasic_RWSiUnitAndThermodynamicTemperatureUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWSiUnitAndThermodynamicTemperatureUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWSiUnitAndThermodynamicTemperatureUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_SiUnitAndThermodynamicTemperatureUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSiUnitAndThermodynamicTemperatureUnit_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_SiUnitAndThermodynamicTemperatureUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSiUnitAndThermodynamicTemperatureUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWSiUnitAndThermodynamicTemperatureUnit

# Register RWStepBasic_RWSiUnitAndThermodynamicTemperatureUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWSiUnitAndThermodynamicTemperatureUnit_swigregister(RWStepBasic_RWSiUnitAndThermodynamicTemperatureUnit)

class RWStepBasic_RWSiUnitAndTimeUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWSiUnitAndTimeUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWSiUnitAndTimeUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_SiUnitAndTimeUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSiUnitAndTimeUnit_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_SiUnitAndTimeUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSiUnitAndTimeUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWSiUnitAndTimeUnit

# Register RWStepBasic_RWSiUnitAndTimeUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWSiUnitAndTimeUnit_swigregister(RWStepBasic_RWSiUnitAndTimeUnit)

class RWStepBasic_RWSiUnitAndVolumeUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWSiUnitAndVolumeUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWSiUnitAndVolumeUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_SiUnitAndVolumeUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSiUnitAndVolumeUnit_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_SiUnitAndVolumeUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSiUnitAndVolumeUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWSiUnitAndVolumeUnit

# Register RWStepBasic_RWSiUnitAndVolumeUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWSiUnitAndVolumeUnit_swigregister(RWStepBasic_RWSiUnitAndVolumeUnit)

class RWStepBasic_RWSolidAngleMeasureWithUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWSolidAngleMeasureWithUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWSolidAngleMeasureWithUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_SolidAngleMeasureWithUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSolidAngleMeasureWithUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_SolidAngleMeasureWithUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSolidAngleMeasureWithUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_SolidAngleMeasureWithUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSolidAngleMeasureWithUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWSolidAngleMeasureWithUnit

# Register RWStepBasic_RWSolidAngleMeasureWithUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWSolidAngleMeasureWithUnit_swigregister(RWStepBasic_RWSolidAngleMeasureWithUnit)

class RWStepBasic_RWSolidAngleUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWSolidAngleUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWSolidAngleUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_SolidAngleUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSolidAngleUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_SolidAngleUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSolidAngleUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_SolidAngleUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWSolidAngleUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWSolidAngleUnit

# Register RWStepBasic_RWSolidAngleUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWSolidAngleUnit_swigregister(RWStepBasic_RWSolidAngleUnit)

class RWStepBasic_RWThermodynamicTemperatureUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWThermodynamicTemperatureUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWThermodynamicTemperatureUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads thermodynamictemperatureunit.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_ThermodynamicTemperatureUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWThermodynamicTemperatureUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_ThermodynamicTemperatureUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWThermodynamicTemperatureUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes thermodynamictemperatureunit.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_ThermodynamicTemperatureUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWThermodynamicTemperatureUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWThermodynamicTemperatureUnit

# Register RWStepBasic_RWThermodynamicTemperatureUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWThermodynamicTemperatureUnit_swigregister(RWStepBasic_RWThermodynamicTemperatureUnit)

class RWStepBasic_RWUncertaintyMeasureWithUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWUncertaintyMeasureWithUnit_swiginit(self, _RWStepBasic.new_RWStepBasic_RWUncertaintyMeasureWithUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_UncertaintyMeasureWithUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWUncertaintyMeasureWithUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepBasic_UncertaintyMeasureWithUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWUncertaintyMeasureWithUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_UncertaintyMeasureWithUnit

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWUncertaintyMeasureWithUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWUncertaintyMeasureWithUnit

# Register RWStepBasic_RWUncertaintyMeasureWithUnit in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWUncertaintyMeasureWithUnit_swigregister(RWStepBasic_RWUncertaintyMeasureWithUnit)

class RWStepBasic_RWVersionedActionRequest(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWVersionedActionRequest_swiginit(self, _RWStepBasic.new_RWStepBasic_RWVersionedActionRequest(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads versionedactionrequest.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_VersionedActionRequest

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWVersionedActionRequest_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepBasic_VersionedActionRequest
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWVersionedActionRequest_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes versionedactionrequest.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_VersionedActionRequest

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWVersionedActionRequest_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWVersionedActionRequest

# Register RWStepBasic_RWVersionedActionRequest in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWVersionedActionRequest_swigregister(RWStepBasic_RWVersionedActionRequest)

class RWStepBasic_RWWeekOfYearAndDayDate(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepBasic.RWStepBasic_RWWeekOfYearAndDayDate_swiginit(self, _RWStepBasic.new_RWStepBasic_RWWeekOfYearAndDayDate(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepBasic_WeekOfYearAndDayDate

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWWeekOfYearAndDayDate_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepBasic_WeekOfYearAndDayDate

        Returns
        -------
        None

        """
        return _RWStepBasic.RWStepBasic_RWWeekOfYearAndDayDate_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepBasic.delete_RWStepBasic_RWWeekOfYearAndDayDate

# Register RWStepBasic_RWWeekOfYearAndDayDate in _RWStepBasic:
_RWStepBasic.RWStepBasic_RWWeekOfYearAndDayDate_swigregister(RWStepBasic_RWWeekOfYearAndDayDate)





